@@ -79,17 +79,19 @@ class PushHandler:
 
 		log.info("decoding...")
 		
-		
 		(data, sndr, url, trans_id) = self.cont.decode_mms_from_push(binarydata)
 		
 		log.info("saving...")
 		# Controller should save it
 		pushid = self.cont.save_push_message(data)
-		log.info("notifying push...")
-		# Send a notify we got the SMS Push and parsed it A_OKEY!
-		self.notify_mms(dbus_loop, sndr, "SMS Push for MMS received")
-		log.info("fetching mms...")
-		path = self._get_mms_message(url, trans_id)
+		try:
+			log.info("fetching mms...")
+			path = self._get_mms_message(url, trans_id)
+		except:
+			log.info("failed to fetch - notifying push...")
+			# Send a notify we got the SMS Push and parsed it A_OKEY!
+			self.notify_mms(dbus_loop, sndr, "SMS Push for MMS received")
+			raise
 		log.info("decoding mms... path: %s", path)
 		message = self.cont.decode_binary_mms(path)
 		log.info("storing mms...")
@@ -98,7 +100,6 @@ class PushHandler:
 		self.notify_mms(dbus_loop, sndr, "New MMS", trans_id);
 		return 0
 
-
 	""" handle incoming ip push """
 	# TODO: implement this
 	def _incoming_ip_push(self, src_ip, dst_ip, src_port, dst_port, wsp_header, wsp_payload):
@@ -106,7 +107,6 @@ class PushHandler:
 			log.info("SRC: %s:%s", src_ip, src_port)
 			log.info("DST: %s:%s", dst_ip, dst_port)
 
-
 	""" notifies the user with a org.freedesktop.Notifications.Notify, really fancy """
 	def notify_mms(self, dbus_loop, sender, message, path=None):
 		bus = dbus.SystemBus()
@@ -118,9 +118,7 @@ class PushHandler:
 		else:
 			interface.Notify("MMS", 0, '', message, sender, choices, {"category": "email-message", "dialog-type": 4, "led-pattern": "PatternCommunicationEmail", "dbus-callback-default": "se.frals.fmms /se/frals/fmms se.frals.fmms open_mms string:\"" + path + "\""}, -1)
 
-
 	def _get_mms_message(self, location, transaction):
-		
 		connector = MasterConnector()
 		connector.connect(location)
 				
@@ -143,9 +141,6 @@ class PushHandler:
 		
 		return dirname
 		
-			
-
-
 	""" get the mms message from content-location """
 	""" thanks benaranguren on talk.maemo.org for patch including x-wap-profile header """
 	def __get_mms_message(self, location, transaction):
@@ -167,7 +162,7 @@ class PushHandler:
 			if proxyurl == "" or proxyurl == None:
 				log.info("connecting without proxy")
 			else:
-				proxyfull = str(proxyurl) + ":" + str(proxyport)
+				proxyfull = "%s:%s" % (str(proxyurl), str(proxyport))
 				log.info("connecting with proxy %s", proxyfull)
 				proxy = urllib2.ProxyHandler({"http": proxyfull})
 				opener = urllib2.build_opener(proxy)
@@ -193,12 +188,11 @@ class PushHandler:
 			bus = dbus.SystemBus()
 			proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
 			interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-			interface.SystemNoteInfoprint ("fMMS: Failed to download MMS message.")
+			interface.SystemNoteInfoprint ("Failed to download MMS message.")
 			raise
 		
 		return dirname
 
-
 	def _send_notify_resp(self, transid):
 		mms = MMSMessage(True)
 		mms.headers['Message-Type'] = "m-notifyresp-ind"
@@ -211,8 +205,7 @@ class PushHandler:
 		out = sender.sendMMS(mms)
 		log.info("m-notifyresp-ind: %s", out)
 		return out
-	
-	
+		
 	def _send_acknowledge(self, transid):
 		mms = MMSMessage(True)
 		mms.headers['Message-Type'] = "m-acknowledge-ind"
@@ -416,8 +409,6 @@ class ICDConnector:
 		else:
 			connection.request_connection(conic.CONNECT_FLAG_NONE)
 		
-		
-		
 
 """ this is the 'force switch' autoconnecter """
 """ credits to Stuart Hopkins for implementing this as
